SecretStore

Trait SecretStore 

pub trait SecretStore: Send + Sync {
    // Required method
    fn get(&self, name: &str) -> Option<String>;
}
Resolution order: env var → SecretStore → prompt.

The one deliberately dyn seam in this crate (rule 2): the implementations really are chosen at runtime and really are heterogeneous.

Required Methods

fn get(&self, name: &str) -> Option<String>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors